from .scales import Scale  # noqa: F401
from .duration import Duration  # noqa: F401
version = (0, 3, 3)

__title__ = "durations"
__author__ = "Oleiade"
__license__ = "MIT"

__version__ = '.'.join(map(str, version))
